"""
    Validation tests
"""
from __future__ import absolute_import

from numpy._pytesttester import PytestTester
test = PytestTester(__name__)
del PytestTester


from .typeset_report import typeset_report
from .run_validation import run_validation_script
from .produce_report import produce_report
from .save_parameters_tex import save_parameters_tex



